# Generated by roxygen2: do not edit by hand

export(aceAnnotate)
export(aceAutocomplete)
export(aceEditor)
export(aceTooltip)
export(getAceModes)
export(getAceThemes)
export(is.empty)
export(updateAceEditor)
import(shiny)
import(tools)
import(utils)
importFrom(jsonlite,toJSON)
importFrom(shiny,getDefaultReactiveDomain)
importFrom(shiny,observe)
importFrom(shiny,observeEvent)
importFrom(shiny,tags)
importFrom(tools,Rd2HTML)
importFrom(utils,compareVersion)
importFrom(utils,packageVersion)
